##  Accessing the SAP Discovery Inbox from the Inventory
**Note**
Only users with admin rights can access the SAP discovery inbox. Admins can grant access to other roles by configuring permissions in the administration area. For more details, see [Role-Based Permissions](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions?locale=en-US&state=PRODUCTION&version=CLOUD#loio275def827a4410149362f3672c614956__role-based_permissions).
Granting permission to non-admin roles is useful when SAP experts and consultants need to review discovered items.
To access the inbox from the inventory, follow these steps:
  1. Go to the Inventory.
  2. Under Inventory Tools, select Discovery Inbox > SAP Discovery.
